bayespy.nodes.CategoricalMarkovChain.lower_bound_contribution
=============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: CategoricalMarkovChain.lower_bound_contribution